package com.jiuqi.dna.ide.designer.parts;

import com.jiuqi.dna.ide.designer.connection.IConnectionAnchorProvider;
import com.jiuqi.dna.ide.designer.elements.DesignerElement;
import com.jiuqi.dna.ide.designer.elements.IDesignerElement;
import com.jiuqi.dna.ide.designer.elements.IFigureElement;
import com.jiuqi.dna.ide.designer.events.DesignerElementAdapter;
import com.jiuqi.dna.ide.designer.events.DesignerElementEvent;
import com.jiuqi.dna.ide.designer.events.FigureAdapter;
import com.jiuqi.dna.ide.designer.events.FigureEvent;
import com.jiuqi.dna.ide.designer.events.IDesignerElementListener;
import com.jiuqi.dna.ide.designer.events.IFigureListener;
import com.jiuqi.dna.ide.designer.figure.IFigureProvider;
import com.jiuqi.dna.ide.designer.policies.FigureElementEditPolicy;
import com.jiuqi.dna.ide.designer.policies.NodeElementEditPolicy;
import java.util.List;
import org.eclipse.draw2d.ConnectionAnchor;
import org.eclipse.draw2d.IFigure;
import org.eclipse.gef.ConnectionEditPart;
import org.eclipse.gef.EditPart;
import org.eclipse.gef.GraphicalEditPart;
import org.eclipse.gef.NodeEditPart;
import org.eclipse.gef.Request;
import org.eclipse.gef.editparts.AbstractGraphicalEditPart;

/* loaded from: com_jiuqi_dna_ide_designer_parts.jar:com/jiuqi/dna/ide/designer/parts/FigureEditPart.class */
public class FigureEditPart extends AbstractGraphicalEditPart implements NodeEditPart {
    private IFigureProvider figureProvider;
    private IConnectionAnchorProvider connectionAnchorProvider;
    private ConnectionAnchor anchor;
    private IDesignerElementListener elementListener = new DesignerElementAdapter() { // from class: com.jiuqi.dna.ide.designer.parts.FigureEditPart.1
        public void elementChangeProperty(DesignerElementEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refresh();
            }
        }
    };
    private IFigureListener figureListener = new FigureAdapter() { // from class: com.jiuqi.dna.ide.designer.parts.FigureEditPart.2
        public void figureMove(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refreshVisuals();
            }
        }

        public void figureResize(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refreshVisuals();
            }
        }

        public void figureLayoutDataChange(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.getParent().refresh();
            }
        }

        public void figureSourceLinkAdd(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refreshSourceConnections();
            }
        }

        public void figureSourceLinkRemove(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refreshSourceConnections();
            }
        }

        public void figureTargetLinkAdd(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refreshTargetConnections();
            }
        }

        public void figureTargetLinkRemove(FigureEvent event) {
            if (event.element == FigureEditPart.this.getModel()) {
                FigureEditPart.this.refreshTargetConnections();
            }
        }
    };

    public void activate() {
        if (!isActive()) {
            super.activate();
            DesignerElement designerElement = (IDesignerElement) getModel();
            if (designerElement instanceof DesignerElement) {
                DesignerElement elem = designerElement;
                elem.getDesigner().addDesignerElementListener(this.elementListener);
                elem.getDesigner().addFigureListener(this.figureListener);
            }
        }
    }

    public void deactivate() {
        if (isActive()) {
            super.deactivate();
            DesignerElement designerElement = (IDesignerElement) getModel();
            if (designerElement instanceof DesignerElement) {
                DesignerElement elem = designerElement;
                elem.getDesigner().removeDesignerElementListener(this.elementListener);
                elem.getDesigner().removeFigureListener(this.figureListener);
            }
        }
    }

    protected IFigure createFigure() {
        return getFigureProvider().getFigure(getCastedModel());
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public void createEditPolicies() {
        installEditPolicy("ComponentEditPolicy", new FigureElementEditPolicy());
        installEditPolicy("GraphicalNodeEditPolicy", new NodeElementEditPolicy());
    }

    protected List<?> getModelSourceConnections() {
        return getCastedModel().getSourceLinks();
    }

    protected List<?> getModelTargetConnections() {
        return getCastedModel().getTargetLinks();
    }

    public ConnectionAnchor getSourceConnectionAnchor(ConnectionEditPart connection) {
        return getConnectionAnchor();
    }

    public ConnectionAnchor getSourceConnectionAnchor(Request request) {
        return getConnectionAnchor();
    }

    public ConnectionAnchor getTargetConnectionAnchor(ConnectionEditPart connection) {
        return getConnectionAnchor();
    }

    public ConnectionAnchor getTargetConnectionAnchor(Request request) {
        return getConnectionAnchor();
    }

    protected void refreshVisuals() {
        EditPart editPart = getParent();
        if (editPart instanceof GraphicalEditPart) {
            getParent().setLayoutConstraint(this, getFigure(), getCastedModel().getBounds());
        }
    }

    private IFigureElement getCastedModel() {
        return (IFigureElement) getModel();
    }

    protected ConnectionAnchor getConnectionAnchor() {
        if (this.anchor == null) {
            this.anchor = getConnectionAnchorProvider().getConnectionAnchor(getCastedModel(), getFigure());
        }
        return this.anchor;
    }

    public IFigureProvider getFigureProvider() {
        return this.figureProvider;
    }

    public void setFigureProvider(IFigureProvider figureProvider) {
        this.figureProvider = figureProvider;
    }

    public IConnectionAnchorProvider getConnectionAnchorProvider() {
        return this.connectionAnchorProvider;
    }

    public void setConnectionAnchorProvider(IConnectionAnchorProvider connectionAnchorProvider) {
        this.connectionAnchorProvider = connectionAnchorProvider;
    }
}
